==> 1.0.1%2B1.tar.gz: ios/Classes/BradySdkApi.swift <==
import Flutter
import BradySdk
import UIKit

public class BradySdkApi: PrinterDiscoveryListener, PrinterUpdateListener {
   
    lazy private var printerDiscovery: PrinterDiscovery = PrinterDiscoveryFactory.getPrinterDiscovery(listeners: listeners)
    var printerDetails: PrinterDetails?
    var listeners: [PrinterDiscoveryListener]
    var foundPrinters = [DiscoveredPrinterInformation]()
    var currentTemplate: Template?
    
    init(){
        listeners = [PrinterDiscoveryListener]()
        listeners.append(self)
    }
    
    public func startPrinterDiscovery() {
        printerDiscovery = PrinterDiscoveryFactory.getPrinterDiscovery(listeners: listeners)
        printerDiscovery.startBlePrinterDiscovery()
    }
    
    public func stopPrinterDiscovery() {
        printerDiscovery.stopBlePrinterDiscovery()
    }
    
    public func getPrinters() -> String {
        var printerNames: String = ""
        for printer in foundPrinters {
            printerNames += printer.getName() + ", "
        }
        return printerNames
    }
    
    public func connectToPrinter(printer: String?) async -> Bool {
        
        var printerObject: DiscoveredPrinterInformation? = nil
        for i in foundPrinters {
            if i.getName() == printer {
                printerObject = i
            }
        }
        
        var listeners: Array<PrinterUpdateListener> = []
        listeners.append(self)
        
        if printerObject != nil {
            printerDetails = await printerDiscovery.connectToDiscoveredPrinter(printerSelected: printerObject!, listeners: listeners)
            if printerDetails != nil {
                return true
            }
            else {
                return false
            }
        }
        else {
            return false
        }
    }
    
    public func getPrinterDetails() -> String {
        var details = ""
        if self.printerDetails != nil {
            details += "Connection Status: " + (self.printerDetails?.getPrinterStatus().rawValue ?? "")
            details += " (" + (self.printerDetails?.getConnectionType().rawValue ?? "") + ")\n"
            details += "Printer Name: " + (self.printerDetails?.getPrinterName() ?? "")
            details += " (" + (self.printerDetails?.getPrinterModel() ?? "") + ")\n"
            details += "Supply Name: " + (self.printerDetails?.getSupplyName() ?? "") + "\n"
            details += "Supply Dimensions: " + (self.printerDetails?.getSupplyDimensions() ?? "") + "\n"
            let remainingSupply: Int = self.printerDetails?.getSupplyRemainingPercentage() ?? 0
            details += "Remaining Supply: " + String(remainingSupply) + "\n"
            let batteryPercentage: Int = self.printerDetails?.getBatteryLevelPercentage() ?? 0
            details += "Battery Level: " + String(batteryPercentage)
            details += ", Charging: " + (self.printerDetails?.getIsAcConnected().description ?? "")
            return details
        }
        return ""
    }
    
    public func getLastConnectedPrinterName() -> String? {
        return self.printerDiscovery.getLastConnectedPrinterName()
    }
    
    public func setTemplate(inputStream: InputStream) {
        self.currentTemplate = TemplateFactory.getTemplate(template: inputStream)
    }
    
    public func setPlaceholderValue(placeholder: String, value: String) {
        if self.currentTemplate != nil {
            do {
                for obj in try self.currentTemplate!.getTemplateData() {
                    if obj.getName() == placeholder {
                        try obj.setValue(value: value)
                    }
                }
            }
            catch {
                return
            }
        }
        Swift.print("Template is null (use setTemplate(inputStream:) first)!")
    }
    
    public func print() async -> Bool {
        if self.currentTemplate != nil {
            let printingOptions: PrintingOptions = PrintingOptions()
            printingOptions.cutOption = CutOption.EndOfLabel
            printingOptions.numberOfCopies = 1
            if printerDetails != nil {
                let printStatus = await printerDetails!.print(template: self.currentTemplate!, printingOptions: printingOptions, dontPrintTrailerFlag: true)
                if printStatus == PrintingStatus.PrintingSucceeded {
                    return true
                }
            }
            Swift.print("Print failed because there is no connection to the desired printer!")
            return false
        }
        Swift.print("Template is null (use setTemplate first)!")
        return false
    }
    
    public func feed() async -> Bool {
        if printerDetails != nil {
            let fed = await printerDetails!.feed() ?? false
            return fed
        }
        Swift.print("Feed failed because there is no connection to the desired printer!")
        return false
    }
    
    public func cut() async -> Bool {
        if printerDetails != nil {
            let cut = await printerDetails!.cutLabel() ?? false
            return cut
        }
        Swift.print("Cut failed because there is no connection to the desired printer!")
        return false
    }
    
    public func disconnect() async -> Bool {
        if printerDetails != nil {
            let disconnected = await printerDetails!.disconnect() ?? false
            if disconnected {
                printerDetails = nil
            }
            return disconnected
        }
        Swift.print("Disconnect failed because there is no connection to the desired printer!")
        return false
    }
    
    public func printerDiscovered(discoveredPrinterInformation: DiscoveredPrinterInformation) {
        if(!foundPrinters.contains(where: {discoveredPrinterInformation.getName() == $0.getName()})) {
            foundPrinters.append(discoveredPrinterInformation)
        }
    }
    
    public func printerDiscoveryStarted() {
        
    }
    
    public func printerDiscoveryStopped() {
        
    }
    
    public func PrinterUpdate(changedProperties: Array<BradySdk.PrinterProperties>) {
        
    }
}

==> 1.0.5%2B1.tar.gz: ios/Classes/BradySdkApi.swift <==
import Flutter
import BradySdk
import UIKit

public class BradySdkApi: PrinterDiscoveryListener, PrinterUpdateListener {
   
    lazy private var printerDiscovery: PrinterDiscovery = PrinterDiscoveryFactory.getPrinterDiscovery(listeners: listeners)
    var printerDetails: PrinterDetails?
    var listeners: [PrinterDiscoveryListener]
    var foundPrinters = [DiscoveredPrinterInformation]()
    var currentTemplate: Template?
    
    init(){
        listeners = [PrinterDiscoveryListener]()
        listeners.append(self)
    }
    
    public func startPrinterDiscovery() {
        printerDiscovery = PrinterDiscoveryFactory.getPrinterDiscovery(listeners: listeners)
        printerDiscovery.startBlePrinterDiscovery()
        printerDiscovery.startWifiPrinterDiscovery()
    }
    
    public func stopPrinterDiscovery() {
        printerDiscovery.stopBlePrinterDiscovery()
    }
    
    public func getPrinters() -> String {
        var printerNames: String = ""
        for printer in foundPrinters {
            printerNames += printer.getName() + ", "
        }
        return printerNames
    }
    
    public func connectToPrinter(printer: String?) async -> Bool {
        
        var printerObject: DiscoveredPrinterInformation? = nil
        for i in foundPrinters {
            if i.getName() == printer {
                printerObject = i
            }
        }
        
        var listeners: Array<PrinterUpdateListener> = []
        listeners.append(self)
        
        if printerObject != nil {
            printerDetails = await printerDiscovery.connectToDiscoveredPrinter(printerSelected: printerObject!, listeners: listeners)
            if printerDetails != nil {
                return true
            }
            else {
                return false
            }
        }
        else {
            return false
        }
    }
    
    public func getPrinterDetails() -> String {
        var details = ""
        if self.printerDetails != nil {
            details += "Connection Status: " + (self.printerDetails?.getPrinterStatus().rawValue ?? "")
            details += " (" + (self.printerDetails?.getConnectionType()?.rawValue ?? "") + ")\n"
            details += "Printer Name: " + (self.printerDetails?.getPrinterName() ?? "")
            details += " (" + (self.printerDetails?.getPrinterModel() ?? "") + ")\n"
            details += "Supply Name: " + (self.printerDetails?.getSupplyName() ?? "") + "\n"
            details += "Supply Dimensions: " + (self.printerDetails?.getSupplyDimensions() ?? "") + "\n"
            let remainingSupply: Int = self.printerDetails?.getSupplyRemainingPercentage() ?? 0
            details += "Remaining Supply: " + String(remainingSupply) + "\n"
            let batteryPercentage: Int = self.printerDetails?.getBatteryLevelPercentage() ?? 0
            details += "Battery Level: " + String(batteryPercentage)
            details += ", Charging: " + (self.printerDetails?.getIsAcConnected().description ?? "")
            return details
        }
        return ""
    }
    
    public func getLastConnectedPrinterName() -> String? {
        return self.printerDiscovery.getLastConnectedPrinterName()
    }
    
    public func setTemplate(inputStream: InputStream) {
        self.currentTemplate = TemplateFactory.getTemplate(template: inputStream)
    }
    
    public func setPlaceholderValue(placeholder: String, value: String) {
        if self.currentTemplate != nil {
            do {
                for obj in try self.currentTemplate!.getTemplateData() {
                    if obj.getName() == placeholder {
                        try obj.setValue(value: value)
                    }
                }
            }
            catch {
                return
            }
        }
        else {
            Swift.print("Template is null (use setTemplate(inputStream:) first)!")
        }
    }
    
    public func print() async -> Bool {
        if self.currentTemplate != nil {
            let printingOptions: PrintingOptions = PrintingOptions()
            printingOptions.cutOption = CutOption.EndOfLabel
            printingOptions.numberOfCopies = 1
            if printerDetails != nil {
                let printStatus = await printerDetails!.print(template: self.currentTemplate!, printingOptions: printingOptions, dontPrintTrailerFlag: true)
                if printStatus == PrintingStatus.PrintingSucceeded {
                    return true
                }
            }
            Swift.print("Print failed because there is no connection to the desired printer!")
            return false
        }
        Swift.print("Template is null (use setTemplate first)!")
        return false
    }
    
    public func feed() async -> Bool {
        if printerDetails != nil {
            let fed = await printerDetails!.feed() ?? false
            return fed
        }
        Swift.print("Feed failed because there is no connection to the desired printer!")
        return false
    }
    
    public func cut() async -> Bool {
        if printerDetails != nil {
            let cut = await printerDetails!.cutLabel() ?? false
            return cut
        }
        Swift.print("Cut failed because there is no connection to the desired printer!")
        return false
    }
    
    public func disconnect() async -> Bool {
        if printerDetails != nil {
            let disconnected = await printerDetails!.disconnect() ?? false
            if disconnected {
                printerDetails = nil
            }
            return disconnected
        }
        Swift.print("Disconnect failed because there is no connection to the desired printer!")
        return false
    }
    
    public func printerDiscovered(discoveredPrinterInformation: DiscoveredPrinterInformation) {
        if(!foundPrinters.contains(where: {discoveredPrinterInformation.getName() == $0.getName()})) {
            foundPrinters.append(discoveredPrinterInformation)
        }
    }
    
    public func printerDiscoveryStarted() {
        
    }
    
    public func printerDiscoveryStopped() {
        
    }
    
    public func PrinterUpdate(changedProperties: Array<BradySdk.PrinterProperties>) {
        
    }
}
